@@ -2,14 +2,14 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.cache import Cache
 from trytond.config import config
-from trytond.model import ModelSQL, ModelSingleton, fields
+from trytond.model import ModelSingleton, ModelSQL, fields
 
 
 class Configuration(ModelSingleton, ModelSQL):
     'Configuration'
     __name__ = 'ir.configuration'
     language = fields.Char('language')
-    hostname = fields.Char("Hostname")
+    hostname = fields.Char("Hostname", strip=False)
     _get_language_cache = Cache('ir_configuration.get_language')
 
     @staticmethod
