@@ -8,11 +8,11 @@ from trytond.config import config
 from trytond.i18n import gettext, lazy_gettext
 from trytond.model import fields
 from trytond.model.exceptions import ValidationError
+from trytond.pool import Pool
 from trytond.pyson import Eval, PYSONDecoder
 from trytond.rpc import RPC
 from trytond.tools import slugify
 from trytond.transaction import Transaction
-from trytond.pool import Pool
 
 
 class DomainError(ValidationError):
@@ -91,6 +91,7 @@ class DictSchemaMixin(object):
         super(DictSchemaMixin, cls).__setup__()
         cls.__rpc__.update({
                 'get_keys': RPC(instantiate=0),
+                'search_get_keys': RPC(),
                 })
 
     @staticmethod
@@ -107,13 +108,15 @@ class DictSchemaMixin(object):
             self.name = slugify(self.string.lower(), hyphenate='_')
 
     @classmethod
-    def validate(cls, schemas):
-        super(DictSchemaMixin, cls).validate(schemas)
-        cls.check_domain(schemas)
-        cls.check_selection(schemas)
+    def validate_fields(cls, schemas, field_names):
+        super().validate_fields(schemas, field_names)
+        cls.check_domain(schemas, field_names)
+        cls.check_selection(schemas, field_names)
 
     @classmethod
-    def check_domain(cls, schemas):
+    def check_domain(cls, schemas, field_names=None):
+        if field_names and 'domain' not in field_names:
+            return
         for schema in schemas:
             if not schema.domain:
                 continue
@@ -129,7 +132,10 @@ class DictSchemaMixin(object):
                         schema=schema.rec_name))
 
     @classmethod
-    def check_selection(cls, schemas):
+    def check_selection(cls, schemas, field_names=None):
+        if field_names and not (field_names & {
+                    'type_', 'selection', 'help_selection'}):
+            return
         for schema in schemas:
             if schema.type_ not in {'selection', 'multiselection'}:
                 continue
@@ -178,6 +184,11 @@ class DictSchemaMixin(object):
             keys.append(new_key)
         return keys
 
+    @classmethod
+    def search_get_keys(cls, domain, limit=None):
+        schemas = cls.search(domain, limit=limit)
+        return cls.get_keys(schemas)
+
     @classmethod
     def get_relation_fields(cls):
         if not config.get('dict', cls.__name__, default=True):
@@ -205,3 +216,29 @@ class DictSchemaMixin(object):
     def delete(cls, records):
         super().delete(records)
         cls._relation_fields_cache.clear()
+
+    def format(self, value, lang=None):
+        pool = Pool()
+        Lang = pool.get('ir.lang')
+        if lang is None:
+            lang = Lang.get()
+        if value is None:
+            return ''
+        if self.type_ == 'boolean':
+            if value:
+                return gettext('ir.msg_dict_yes')
+            else:
+                return gettext('ir.msg_dict_no')
+        elif self.type_ == 'integer':
+            return lang.format('%i', value)
+        elif self.type_ in {'float', 'numeric'}:
+            return lang.format('%.*f', (self.digits, value))
+        elif self.type_ in {'date', 'datetime'}:
+            return lang.strftime(value)
+        elif self.type_ in {'selection', 'multiselection'}:
+            values = dict(json.loads(self.selection_json))
+            if self.type_ == 'selection':
+                return values.get(value, '')
+            else:
+                return "; ".join(values.get(v, '') for v in value)
+        return value
