@@ -147,7 +147,7 @@ class Exclude(Constraint):
             for column, operator in self.excludes)
         where = ''
         if self.where:
-            where = ' WHERE ' + str(self.where)
+            where = ' WHERE (' + str(self.where) + ')'
         return 'EXCLUDE (%s)' % exclude + where
 
     @property
