@@ -1,16 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import logging
-import time
 import random
-
-from werkzeug.exceptions import abort
+import time
 
 from trytond.config import config
-from trytond.wsgi import app
 from trytond.protocols.wrappers import (
-    with_pool, with_transaction, allow_null_origin)
+    abort, allow_null_origin, with_pool, with_transaction)
 from trytond.transaction import Transaction
+from trytond.wsgi import app
 
 logger = logging.getLogger(__name__)
 
@@ -44,7 +42,7 @@ def user_application(request, pool):
             user_id = None
         data['user'] = user_id
         data.pop('key', None)
-        data.pop('state', None)
+        data['state'] = 'requested'
         application, = UserApplication.create([data])
         key = application.key
         UserApplication.delete(UserApplication.search([
