@@ -7,10 +7,10 @@ from sql import Literal
 
 from trytond import backend
 from trytond.model.exceptions import (
-    RequiredValidationError, ForbiddenCharValidationError)
+    ForbiddenCharValidationError, RequiredValidationError, SizeValidationError)
 from trytond.pool import Pool
-from trytond.tests.test_tryton import activate_module, with_transaction
-from trytond.tests.test_tryton import ExtensionTestCase
+from trytond.tests.test_tryton import (
+    ExtensionTestCase, activate_module, with_transaction)
 from trytond.transaction import Transaction
 
 
@@ -41,15 +41,6 @@ class CommonTestCaseMixin:
 
         self.assertEqual(char.char, "é")
 
-    @with_transaction()
-    def test_create_with_sql_value(self):
-        "Test create with SQL value"
-        Char = self.Char()
-
-        char, = Char.create([{'char': Literal('Foo')}])
-
-        self.assertEqual(char.char, "Foo")
-
     @with_transaction()
     def test_search_equals(self):
         "Test search char equals"
@@ -332,6 +323,64 @@ class CommonTestCaseMixin:
 
         self.assertEqual(char.char, "é")
 
+    @with_transaction()
+    def test_create_strip(self):
+        "Test create with stripping"
+        Char = self.Char()
+
+        char, = Char.create([{
+                    'char': " Foo ",
+                    'char_lstripped': " Foo ",
+                    'char_rstripped': " Foo ",
+                    'char_unstripped': " Foo ",
+                    }])
+
+        read_record = Char(char.id)
+        self.assertEqual(read_record.char, "Foo")
+        self.assertEqual(read_record.char_lstripped, "Foo ")
+        self.assertEqual(read_record.char_rstripped, " Foo")
+        self.assertEqual(read_record.char_unstripped, " Foo ")
+
+    @with_transaction()
+    def test_write_strip(self):
+        "Test write with stripping"
+        Char = self.Char()
+
+        char, = Char.create([{
+                    'char': "Foo",
+                    'char_lstripped': "Foo",
+                    'char_rstripped': "Foo",
+                    'char_unstripped': "Foo",
+                    }])
+
+        Char.write([char], {
+                'char': " Bar ",
+                'char_lstripped': " Bar ",
+                'char_rstripped': " Bar ",
+                'char_unstripped': " Bar ",
+                })
+        read_record = Char(char.id)
+        self.assertEqual(read_record.char, "Bar")
+        self.assertEqual(read_record.char_lstripped, "Bar ")
+        self.assertEqual(read_record.char_rstripped, " Bar")
+        self.assertEqual(read_record.char_unstripped, " Bar ")
+
+    @with_transaction()
+    def test_set_strip(self):
+        "Test set with stripping"
+        Char = self.Char()
+
+        char = Char()
+
+        char.char = " Foo "
+        char.char_lstripped = " Foo "
+        char.char_rstripped = " Foo "
+        char.char_unstripped = " Foo "
+        self.assertEqual(char.char, "Foo")
+        self.assertEqual(char.char_lstripped, "Foo ")
+        self.assertEqual(char.char_rstripped, " Foo")
+        self.assertEqual(char.char_unstripped, " Foo ")
+
 
 class FieldCharTestCase(unittest.TestCase, CommonTestCaseMixin):
     "Test Field Char"
@@ -343,6 +392,25 @@ class FieldCharTestCase(unittest.TestCase, CommonTestCaseMixin):
     def Char(self):
         return Pool().get('test.char')
 
+    @with_transaction()
+    def test_create_with_sql_value(self):
+        "Test create with SQL value"
+        Char = self.Char()
+
+        char, = Char.create([{'char': Literal('Foo')}])
+
+        self.assertEqual(char.char, "Foo")
+
+    @with_transaction()
+    def test_set_sql_value(self):
+        "Test cannot set SQL value"
+        Char = self.Char()
+
+        char = Char()
+
+        with self.assertRaises(ValueError):
+            char.char = Literal('Foo')
+
     @with_transaction()
     def test_create_without_default(self):
         "Test create char without default"
@@ -406,12 +474,45 @@ class FieldCharTestCase(unittest.TestCase, CommonTestCaseMixin):
         "Test create char with invalid size"
         Char = Pool().get('test.char_size')
 
-        # XXX: should be UserError but postgresql raises DataError
-        with self.assertRaises(Exception):
+        with self.assertRaises(SizeValidationError):
             Char.create([{
                         'char': "foobar",
                         }])
 
+    @with_transaction()
+    def test_create_size_pyson_valid(self):
+        "Test create char with PYSON size"
+        Char = Pool().get('test.char_size_pyson')
+
+        char, = Char.create([{
+                    'char': "Test",
+                    'size': 5,
+                    }])
+
+        self.assertEqual(char.char, "Test")
+
+    @with_transaction()
+    def test_create_size_pyson_invalid(self):
+        "Test create char with invalid PYSON size"
+        Char = Pool().get('test.char_size_pyson')
+
+        with self.assertRaises(SizeValidationError):
+            Char.create([{
+                        'char': "foobar",
+                        'size': 5,
+                        }])
+
+    @with_transaction()
+    def test_create_size_pyson_none(self):
+        "Test create char with PYSON size as None"
+        pool = Pool()
+        Char = pool.get('test.char_size_pyson')
+
+        char, = Char.create([{
+                    'char': "foo",
+                    'size': None,
+                    }])
+
     @with_transaction()
     def test_create_invalid_char(self):
         "Test create char with invalid char"
@@ -459,12 +560,53 @@ class FieldCharTestCase(unittest.TestCase, CommonTestCaseMixin):
                     'char': "Test",
                     }])
 
-        # XXX: should be UserError but postgresql raises DataError
-        with self.assertRaises(Exception):
+        with self.assertRaises(SizeValidationError):
             Char.write([char], {
                     'char': 'foobar',
                     })
 
+    @with_transaction()
+    def test_create_strip_with_sql_value(self):
+        "Test create with stripping with SQL value"
+        Char = self.Char()
+
+        char, = Char.create([{
+                    'char': Literal(" Foo "),
+                    'char_lstripped': Literal(" Foo "),
+                    'char_rstripped': Literal(" Foo "),
+                    'char_unstripped': Literal(" Foo "),
+                    }])
+
+        read_record = Char(char.id)
+        self.assertEqual(read_record.char, "Foo")
+        self.assertEqual(read_record.char_lstripped, "Foo ")
+        self.assertEqual(read_record.char_rstripped, " Foo")
+        self.assertEqual(read_record.char_unstripped, " Foo ")
+
+    @with_transaction()
+    def test_write_strip_with_sql_value(self):
+        "Test write with stripping with SQL value"
+        Char = self.Char()
+
+        char, = Char.create([{
+                    'char': "Foo",
+                    'char_lstripped': "Foo",
+                    'char_rstripped': "Foo",
+                    'char_unstripped': "Foo",
+                    }])
+
+        Char.write([char], {
+                'char': Literal(" Bar "),
+                'char_lstripped': Literal(" Bar "),
+                'char_rstripped': Literal(" Bar "),
+                'char_unstripped': Literal(" Bar "),
+                })
+        read_record = Char(char.id)
+        self.assertEqual(read_record.char, "Bar")
+        self.assertEqual(read_record.char_lstripped, "Bar ")
+        self.assertEqual(read_record.char_rstripped, " Bar")
+        self.assertEqual(read_record.char_unstripped, " Bar ")
+
 
 class FieldCharTranslatedTestCase(unittest.TestCase, CommonTestCaseMixin):
     "Test Field Char Translated"
@@ -476,10 +618,18 @@ class FieldCharTranslatedTestCase(unittest.TestCase, CommonTestCaseMixin):
     def Char(self):
         return Pool().get('test.char_translate')
 
+    @with_transaction()
+    def test_create_with_sql_value(self):
+        "Test cannot create with SQL value"
+        Char = self.Char()
+
+        with self.assertRaises(ValueError):
+            Char.create([{'char': Literal('Foo')}])
+
     @with_transaction()
     def test_translation_default_language_cache(self):
-        """Test set translation for default language does not fill transactional
-        cache with former value"""
+        """Test set translation for default language does not fill
+        transactional cache with former value"""
         pool = Pool()
         Config = pool.get('ir.configuration')
         Char = self.Char()
@@ -634,13 +784,3 @@ class FieldCharSimilarityTestCase(ExtensionTestCase):
         "Test order translated"
         pool = Pool()
         self._test_order(pool.get('test.char_translate'))
-
-
-def suite():
-    suite_ = unittest.TestSuite()
-    loader = unittest.TestLoader()
-    suite_.addTests(loader.loadTestsFromTestCase(FieldCharTestCase))
-    suite_.addTests(loader.loadTestsFromTestCase(FieldCharTranslatedTestCase))
-    suite_.addTests(loader.loadTestsFromTestCase(FieldCharUnaccentedTestCase))
-    suite_.addTests(loader.loadTestsFromTestCase(FieldCharSimilarityTestCase))
-    return suite_
