@@ -70,6 +70,46 @@ class SearchTestCaseMixin:
 
         self.assertListEqual(one2manys, [one2many2])
 
+    @with_transaction()
+    def test_search_equals_none_inactive(self):
+        "Test search one2many equals None when the target is inactive"
+        One2Many = self.One2ManyActive()
+        one2many1, one2many2, one2many3 = One2Many.create([{
+                    'targets': [('create', [{'name': "Target1"}])],
+                    }, {
+                    'targets': [
+                        ('create', [{'name': "Target2", 'active': False}]),
+                        ],
+                    }, {
+                    'targets': None,
+                    }])
+
+        one2manys = One2Many.search([
+                ('targets', '=', None),
+                ])
+
+        self.assertEqual(one2manys, [one2many2, one2many3])
+
+    @with_transaction()
+    def test_search_not_equals_none_inactive(self):
+        "Test search one2many not equals None when the target is inactive"
+        One2Many = self.One2ManyActive()
+        one2many1, one2many2, one2many3 = One2Many.create([{
+                    'targets': [('create', [{'name': "Target1"}])],
+                    }, {
+                    'targets': [
+                        ('create', [{'name': "Target2", 'active': False}]),
+                        ],
+                    }, {
+                    'targets': None,
+                    }])
+
+        one2manys = One2Many.search([
+                ('targets', '!=', None),
+                ])
+
+        self.assertEqual(one2manys, [one2many1])
+
     @with_transaction()
     def test_search_non_equals_none(self):
         "Test search one2many non equals None"
@@ -464,6 +504,9 @@ class FieldOne2ManyTestCase(
     def One2ManyTarget(self):
         return Pool().get('test.one2many.target')
 
+    def One2ManyActive(self):
+        return Pool().get('test.one2many.active')
+
     @with_transaction()
     def test_create_required_with_value(self):
         "Test create one2many required with value"
@@ -610,6 +653,21 @@ class FieldOne2ManyTestCase(
         self.assertEqual(len(filtered.targets), 4)
         self.assertEqual(filtered_target.value, 3)
 
+    @with_transaction()
+    def test_search_equals_filter(self):
+        "Test search one2many equals with filter"
+        One2Many = Pool().get('test.one2many_filter')
+        one2many, = One2Many.create([{
+                    'targets': [('create', [{'value': 3}])],
+                    }])
+
+        one2manys = One2Many.search([('targets', '=', None)])
+        one2manys_filtered = One2Many.search(
+            [('filtered_targets', '=', None)])
+
+        self.assertListEqual(one2manys, [])
+        self.assertListEqual(one2manys_filtered, [])
+
     @with_transaction()
     def test_search_non_equals_filter(self):
         "Test search one2many non equals with filter"
@@ -709,6 +767,9 @@ class FieldOne2ManyReferenceTestCase(
     def One2ManyTarget(self):
         return Pool().get('test.one2many_reference.target')
 
+    def One2ManyActive(self):
+        return Pool().get('test.one2many_reference.active')
+
 
 class FieldOne2ManyExistsTestCase(unittest.TestCase, SearchTestCaseMixin):
     "Test Field One2Many when using EXISTS"
@@ -732,6 +793,9 @@ class FieldOne2ManyExistsTestCase(unittest.TestCase, SearchTestCaseMixin):
     def One2ManyTarget(self):
         return Pool().get('test.one2many.target')
 
+    def One2ManyActive(self):
+        return Pool().get('test.one2many.active')
+
 
 class FieldOne2ManyReferenceExistsTestCase(
         unittest.TestCase, SearchTestCaseMixin):
@@ -756,5 +820,8 @@ class FieldOne2ManyReferenceExistsTestCase(
     def One2ManyTarget(self):
         return Pool().get('test.one2many_reference.target')
 
+    def One2ManyActive(self):
+        return Pool().get('test.one2many_reference.active')
+
     def assert_strategy(self, query):
         self.assertIn('EXISTS', query)
