@@ -3,9 +3,10 @@
 # this repository contains the full copyright notices and license terms.
 import unittest
 from datetime import datetime
-from trytond.tests.test_tryton import install_module, with_transaction
-from trytond.transaction import Transaction
+
 from trytond.pool import Pool
+from trytond.tests.test_tryton import activate_module, with_transaction
+from trytond.transaction import Transaction
 
 
 class ModelSingletonTestCase(unittest.TestCase):
@@ -13,7 +14,7 @@ class ModelSingletonTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        install_module('tests')
+        activate_module('tests')
 
     @with_transaction()
     def test_read(self):
@@ -22,12 +23,12 @@ class ModelSingletonTestCase(unittest.TestCase):
         Singleton = pool.get('test.singleton')
 
         singleton, = Singleton.read([1], ['name'])
-        self.assert_(singleton['name'] == 'test')
-        self.assert_(singleton['id'] == 1)
+        self.assertTrue(singleton['name'] == 'test')
+        self.assertTrue(singleton['id'] == 1)
 
         singleton, = Singleton.read([1], ['name'])
-        self.assert_(singleton['name'] == 'test')
-        self.assert_(singleton['id'] == 1)
+        self.assertTrue(singleton['name'] == 'test')
+        self.assertTrue(singleton['id'] == 1)
 
         singleton, = Singleton.read([1], [
             'create_uid',
@@ -37,8 +38,8 @@ class ModelSingletonTestCase(unittest.TestCase):
             'write_date',
             ])
         self.assertEqual(singleton['create_uid'], Transaction().user)
-        self.assertEqual(singleton['create_uid.rec_name'], 'Administrator')
-        self.assert_(isinstance(singleton['create_date'], datetime))
+        self.assertEqual(singleton['create_uid.']['rec_name'], 'Administrator')
+        self.assertTrue(isinstance(singleton['create_date'], datetime))
         self.assertEqual(singleton['write_uid'], None)
         self.assertEqual(singleton['write_date'], None)
 
@@ -49,7 +50,7 @@ class ModelSingletonTestCase(unittest.TestCase):
         Singleton = pool.get('test.singleton')
 
         singleton, = Singleton.create([{'name': 'bar'}])
-        self.assert_(singleton)
+        self.assertTrue(singleton)
         self.assertEqual(singleton.name, 'bar')
 
         singleton2, = Singleton.create([{'name': 'foo'}])
@@ -115,10 +116,10 @@ class ModelSingletonTestCase(unittest.TestCase):
         Singleton = pool.get('test.singleton')
 
         singletons = Singleton.search([])
-        self.assertEqual(map(int, singletons), [1])
+        self.assertEqual(list(map(int, singletons)), [1])
 
         singletons = Singleton.search([])
-        self.assertEqual(map(int, singletons), [1])
+        self.assertEqual(list(map(int, singletons)), [1])
 
         count = Singleton.search([], count=True)
         self.assertEqual(count, 1)
@@ -129,6 +130,20 @@ class ModelSingletonTestCase(unittest.TestCase):
         singletons = Singleton.search([('name', '=', 'bar')])
         self.assertEqual(singletons, [])
 
+    @with_transaction()
+    def test_all_cache_cleared(self):
+        "Test all cache cleared"
+        pool = Pool()
+        Singleton = pool.get('test.singleton')
 
-def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(ModelSingletonTestCase)
+        singleton, = Singleton.create([{'name': 'foo'}])
+        singleton.name  # Fill the cache
+        singleton2 = Singleton(singleton.id + 1)  # Use a different id
+        singleton2.name  # Fill the cache
+        Singleton.write([singleton], {'name': 'bar'})
+        singleton2 = Singleton(singleton2.id)  # Clear local cache
+
+        self.assertEqual(singleton2.name, 'bar')
+
+        Singleton.delete([singleton])
+        self.assertEqual(singleton2.name, 'test')
