@@ -3,15 +3,15 @@
 
 import unittest
 
-from trytond.tests.test_tryton import install_module, with_transaction
 from trytond.pool import Pool
+from trytond.tests.test_tryton import activate_module, with_transaction
 
 
 class WorkflowTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        install_module('tests')
+        activate_module('tests')
 
     # TODO add test for Workflow.transition
     @with_transaction()
@@ -29,7 +29,3 @@ class WorkflowTestCase(unittest.TestCase):
         wkf.save()
         Workflowed.run([wkf])
         self.assertEqual(wkf.state, 'end')
-
-
-def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(WorkflowTestCase)
