@@ -1,14 +1,15 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from proteus import config as pconfig, Model, Wizard
+from proteus import Model, Wizard
+from proteus import config as pconfig
 
-from .test_tryton import restore_db_cache, backup_db_cache, drop_create
+from .test_tryton import backup_db_cache, drop_create, restore_db_cache
 
 __all__ = ['activate_modules', 'set_user']
 
 
 def activate_modules(modules):
-    if isinstance(modules, basestring):
+    if isinstance(modules, str):
         modules = [modules]
     cache_name = '-'.join(modules)
     if restore_db_cache(cache_name):
@@ -17,10 +18,11 @@ def activate_modules(modules):
 
     cfg = _get_config()
     Module = Model.get('ir.module')
-    modules = Module.find([
+    records = Module.find([
             ('name', 'in', modules),
             ])
-    Module.click(modules, 'activate')
+    assert len(records) == len(modules)
+    Module.click(records, 'activate')
     Wizard('ir.module.activate_upgrade').execute('upgrade')
 
     backup_db_cache(cache_name)
